@@ -425,7 +425,14 @@ gsBoundSummary0 <- function(
   if (!("gsSurv" %in% class(x))) {
     if (x$n.fix > 1) N <- ceiling(x$n.I) else N <- round(x$n.I, 2)
     if (Nname == "Information") N <- round(x$n.I, 2)
-    nstat <- 2
+    # Check if calendar time T is provided (for non-gsSurv objects like gsNB)
+    if (inherits(x, "gsNB") && !is.null(x$T)) {
+      nstat <- 3
+      Time <- round(x$T, tdigits)
+      statframe[statframe$Value == statframe$Value[3], ]$Analysis <- paste(timename, ": ", as.character(Time), sep = "")
+    } else {
+      nstat <- 2
+    }
   } else {
     nstat <- 4
     statframe[statframe$Value == statframe$Value[3], ]$Analysis <- paste("Events:", ceiling(x$n.I))
